==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-calendar-date-event-args.js <==
import { IgrCalendarDate } from "./igr-calendar-date";
import { CalendarDateEventArgs as CalendarDateEventArgs_internal } from "./CalendarDateEventArgs";
var IgrCalendarDateEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrCalendarDateEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrCalendarDateEventArgs.prototype.createImplementation = function () {
        return new CalendarDateEventArgs_internal();
    };
    Object.defineProperty(IgrCalendarDateEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCalendarDateEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrCalendarDateEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrCalendarDateEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrCalendarDate();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCalendarDateEventArgs;
}());
export { IgrCalendarDateEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-calendar-date-event-args.js <==
import { IgrCalendarDate } from "./igr-calendar-date";
import { CalendarDateEventArgs as CalendarDateEventArgs_internal } from "./CalendarDateEventArgs";
var IgrCalendarDateEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrCalendarDateEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrCalendarDateEventArgs.prototype.createImplementation = function () {
        return new CalendarDateEventArgs_internal();
    };
    Object.defineProperty(IgrCalendarDateEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrCalendarDateEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrCalendarDateEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrCalendarDateEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.a;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrCalendarDate();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrCalendarDateEventArgs;
}());
export { IgrCalendarDateEventArgs };
